package MT::Plugin::BuildFileFilter4OldEntry;
use strict;

# コンテンツ管理のベース

use MT;
use MT::Template::Context;
use MT::Plugin;

our $VERSION = "0.1";

@MT::Plugin::BuildFileFilter4OldEntry::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::BuildFileFilter4OldEntry({
	name => 'BuildFileFilter4OldEntry',
	version => $VERSION,
	description => 'BuildFileFilter for Old Entry Archive',
	author_name => 'Junnama Noda',
	author_link => 'http://junnama.alfasado.net/online/',
	settings => new MT::PluginSettings([
		['filter_active', { Default => 0 }],
		['filter_by_date', { Default => 180 }],
		['check_field', { Default => 1 }],
	]),
	system_config_template => 'BuildFileFilter4OldEntry.tmpl',
});

MT->add_plugin($plugin);
MT->add_callback('BuildFileFilter', 1, $plugin, \&_modified_check);
MT::Template::Context->add_conditional_tag(IfOlderEntry => \&_IfOlderEntry);

######################################### Mainroutine #########################################

my $filter_active = $plugin->get_config_value('filter_active');
my $filter_by_date = $plugin->get_config_value('filter_by_date');
my $check_field = $plugin->get_config_value('check_field');
$filter_by_date = $filter_by_date * 86400;


sub _modified_check {
	my ($eh, %args) = @_;
	#my $blog = $args{'Blog'};
	if ($filter_active) {
		my $entry = $args{'Entry'};
		my $at = $args{'ArchiveType'};
		if ($at eq 'Individual') {
			if (defined $entry) {
				my $date_on;
				if ($check_field) {
					$date_on = $entry->created_on;
				} else {
					$date_on = $entry->modified_on;
				}
				$date_on = &get_unixtime($date_on);
				if (time - $date_on > $filter_by_date) {
					return 0;
				}
			}
		}
	}
	return 1;
}

sub _IfOlderEntry {
	my ($ctx, $args, $cond) = @_;
	unless ($filter_active) {
		my $entry = $ctx->stash('entry') or return $ctx->_no_entry_error('IfOlderEntry');
		if (defined $entry) {
			my $date_on;
			if ($check_field) {
				$date_on = $entry->created_on;
			} else {
				$date_on = $entry->modified_on;
			}
			$date_on = &get_unixtime($date_on);
			if (time - $date_on > $filter_by_date) {
				return 1;
			}
		}
	}
	return 0;
}

sub get_unixtime {
	my $ck_date = shift;
	my $myear = substr($ck_date,0,4); my $mmonth = substr($ck_date,4,2);
	my $mday = substr($ck_date,6,2); my $mhour = substr($ck_date,8,2);
	my $mminutes = substr($ck_date,10,2); my $unixtime = 0;
	for (my $i = 1970; $i < $myear; $i++) {
		my $yeardays = ($i % 4 == 0 && ($i % 400 == 0 || $i % 100 != 0)) ? 366 : 365;
		$unixtime = $unixtime + $yeardays;
	}
	my @days_in_month = (31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
	for (my $i = 1; $i < $mmonth; $i++) {
		my $monthdays = ($i == 2 && $myear % 4 == 0 && ($myear % 400 == 0 || $myear % 100 != 0)) ? 29 : $days_in_month[$i-1];
		$unixtime = $unixtime + $monthdays;
	}
	$unixtime = $unixtime + $mday - 1;
	$unixtime = $unixtime * 86400;
	$unixtime = $unixtime + $mhour * 3600;
	$unixtime = $unixtime + $mminutes * 60;
	return $unixtime;
}


1;


